<?php

namespace Drupal\remove_meta_and_headers\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Listener for handling Response Header.
 */
class RemoveResponseHeaders implements EventSubscriberInterface {

  /**
   * Register response headers item remove handler.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *   The event to process.
   */
  public function RemoveResponseHeadersItem(FilterResponseEvent $event) {
    $response = $event->getResponse();

    $config = \Drupal::config('remove_meta_and_headers.settings');

    // If TRUE, fire event to remove X-Generator from Response.
    if (1 == $config->get('response_header_x_generator')) {
      $response->headers->remove('X-Generator');
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::RESPONSE][] = ['RemoveResponseHeadersItem', -10];
    return $events;
  }

}
